Documentation
¶
Index ¶
- Variables
- type PgxDB
- func (db *PgxDB) Close()
- func (db *PgxDB) ExecActionQuery(sql string, arguments ...interface{}) (rowsAffected int, err error)
- func (db *PgxDB) GetQueryBool(sql string, arguments ...interface{}) (result bool, err error)
- func (db *PgxDB) GetQueryInt(sql string, arguments ...interface{}) (result int, err error)
- func (db *PgxDB) GetQueryString(sql string, arguments ...interface{}) (result string, err error)
Constants ¶
This section is empty.
Variables ¶
var ( ErrNoRecordFound = errors.New("record not found") ErrCouldNotBeCreated = errors.New("could not be created in DB") )
Functions ¶
This section is empty.
Types ¶
type PgxDB ¶
func GetPgxConn ¶
func (*PgxDB) Close ¶
func (db *PgxDB) Close()
Close is a postgres helper function to close the connection to the database
func (*PgxDB) ExecActionQuery ¶
func (db *PgxDB) ExecActionQuery(sql string, arguments ...interface{}) (rowsAffected int, err error)
ExecActionQuery is a postgres helper function for an action query, returning the numbers of rows affected
func (*PgxDB) GetQueryBool ¶
GetQueryBool is a postgres helper function for a query expecting an integer result
func (*PgxDB) GetQueryInt ¶
GetQueryInt is a postgres helper function for a query expecting an integer result
Click to show internal directories.
Click to hide internal directories.